@@ -14,4 +14,4 @@ def clean_text(text: str) -> str:
     """
     text = unidecode(text.lower())
     text = re.sub('^[a-z0-9]+', ' ', text)
-    return text
\ No newline at end of file
+    return text.strip()
\ No newline at end of file
